|pypi| |actions| |codecov| |downloads|


edc-prn
-------

Classes and utils to support PRN forms


.. |pypi| image:: https://img.shields.io/pypi/v/edc-prn.svg
    :target: https://pypi.python.org/pypi/edc-prn

.. |actions| image:: https://github.com/clinicedc/edc-prn/workflows/build/badge.svg?branch=develop
  :target: https://github.com/clinicedc/edc-prn/actions?query=workflow:build

.. |codecov| image:: https://codecov.io/gh/clinicedc/edc-prn/branch/develop/graph/badge.svg
  :target: https://codecov.io/gh/clinicedc/edc-prn

.. |downloads| image:: https://pepy.tech/badge/edc-prn
   :target: https://pepy.tech/project/edc-prn
